==> open-xchange-documents-backend_7.6.3.orig.tar.bz2: open-xchange-documents-backend-7.6.3/com.openexchange.office.odf/odfdom/src/main/java/org/odftoolkit/odfdom/component/OperationConstants.java <==
/*
 * Copyright 2012 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.odftoolkit.odfdom.component;

public class OperationConstants{
    public static final String AUTOFILTER = "AutoFilter";
    public static final String AUTOFILTERCOLUMN = "AutoFilterColumn";
    public static final String CELLS = "Cells";
    public static final String TABLE = "Table";
    public static final String EXCEEDEDTABLE = "ExceededTable";
    public static final String ROWS = "Rows";
    public static final String COLUMNS = "Columns";
    // a range is currently only used within spreadsheet documents to optimize the data transfer
    public static final String RANGE = "Range";
    public static final String PARAGRAPH = "Paragraph";
    public static final String IMAGE = "Image";
    public static final String SHAPE = "Shape";
    public static final String GROUP = "Group";
    public static final String HARD_BREAK = "HardBreak";
    public static final String TAB = "Tab";
    public static final String TEXT = "Text";
    public static final String FIELD = "Field";
    public static final String ATTRIBUTES = "Attributes";
    public static final String FORMATROWS = "FormatRows";
    public static final String REMOVEFORMAT = "RemoveFormat";
    public static final String FORMATCOLUMNS = "FormatColumns";
    
}

==> open-xchange-documents-backend_7.8.0.orig.tar.bz2: open-xchange-documents-backend-7.8.0/com.openexchange.office.odf/odfdom/src/main/java/org/odftoolkit/odfdom/component/OperationConstants.java <==
/*
 * Copyright 2012 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.odftoolkit.odfdom.component;

public class OperationConstants{
    public static final String CELLS = "Cells";
    public static final String TABLE = "Table";
    public static final String EXCEEDEDTABLE = "ExceededTable";
    public static final String ROWS = "Rows";
    public static final String COLUMNS = "Columns";
    public static final String PARAGRAPH = "Paragraph";
    public static final String IMAGE = "Image";
    public static final String SHAPE = "Shape";
    public static final String GROUP = "Group";
    public static final String HARD_BREAK = "HardBreak";
    public static final String TAB = "Tab";
    public static final String TEXT = "Text";
    public static final String FIELD = "Field";
    public static final String ATTRIBUTES = "Attributes";
    public static final String FORMATROWS = "FormatRows";
    public static final String FORMATCOLUMNS = "FormatColumns";
    public static final String MERGECELLS = "MergeCells";
    public static final String COMMENTRANGE = "CommentRange";
    public static final String COMMENT = "Comment";
}
